Skip to contents

Implements two statistical tests from VanderWeele and Vansteelandt (2022) to reject the structural interpretation of a univariate latent factor model.

Main functions

test_t0

Reliability-dependent test (Section 3.2). Requires d >= 3 indicators and p >= 2 Z-levels.

test_t1

Reliability-independent test (Section 3.3). Requires d >= 2 indicators and p >= 3 Z-levels.

estimate_reliability

Estimate reliability coefficients via quasi-Poisson GLM (Section 3.1).

fit_structural

Fit the structural model with GMM sandwich standard errors for all free parameters.

References

VanderWeele, T. J., & Vansteelandt, S. (2022). A statistical test to reject the structural interpretation of a latent factor model. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 84(5), 2032–2054. doi:10.1111/rssb.12555

Author

Maintainer: Felipe Fontana Vieira felipelfv98@gmail.com